"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.browserAssetOpts = exports.FAR_FUTURE_TTL_WITH_UNIT = exports.EDGIO_NUXT_CONFIG_PATH = void 0;
const path_1 = require("path");
const assets_1 = require("./assets");
const environment_1 = require("@edgio/core/environment");
const router_1 = require("@edgio/core/router");
exports.EDGIO_NUXT_CONFIG_PATH = '.edgio/edgio-nuxt.config.json';
exports.FAR_FUTURE_TTL_WITH_UNIT = '10y';
const FAR_FUTURE_CACHE_CONFIG = {
    browser: {
        maxAgeSeconds: exports.FAR_FUTURE_TTL_WITH_UNIT,
    },
    edge: {
        maxAgeSeconds: exports.FAR_FUTURE_TTL_WITH_UNIT,
    },
};
exports.browserAssetOpts = {
    permanent: true,
    exclude: ['service-worker.js', 'LICENSES'],
};
class NuxtRoutes {
    /**
     * Provides nuxt registered routes to router
     */
    constructor() {
        this.buildDir = '';
        this.config = {};
        if ((0, environment_1.isProductionBuild)()) {
            this.config = JSON.parse((0, assets_1.readAsset)(exports.EDGIO_NUXT_CONFIG_PATH));
            // if static, we don't have routesManifest (nor do we need it), as that is generated during "nuxt build", not "nuxt generate"
            // these two nuxt "build" approaches are exclusive to each other in v2, eg. there's no way to use both
            if (this.config.target !== 'static') {
                this.buildDir = '.nuxt';
                if (this.config.buildDir) {
                    console.log('> Found buildDir inside nuxt.config.* to be', `"${this.config.buildDir}"`);
                    this.buildDir = this.config.buildDir;
                }
            }
        }
    }
    /**
     * Called when plugin is registered. Creates a route group and add all nuxt routes into it.
     * @param {Router} router
     */
    onRegister(router) {
        this.router = router;
        this.addFallback();
        this.addNuxtRoutes();
        this.router.use(router_1.edgioRoutes);
    }
    /**
     * Adds catchAll route
     */
    addFallback() {
        var _a, _b, _c, _d;
        if (this.config.target === 'static') {
            const fallback = (_b = (_a = this.config) === null || _a === void 0 ? void 0 : _a.generate) === null || _b === void 0 ? void 0 : _b.fallback;
            let targetPage;
            if (fallback === true) {
                // Display the custom 404 page
                targetPage = (0, path_1.join)('dist', '404.html');
            }
            else if (fallback === false) {
                return;
            }
            else if (typeof fallback === 'string') {
                // Display the custom fallback page
                targetPage = (0, path_1.join)('dist', `${fallback}`);
            }
            else {
                // 200.html is generated by default
                targetPage = (0, path_1.join)('dist', '200.html');
            }
            this.log('[@edgio/nuxt] fallback', targetPage);
            (_c = this.router) === null || _c === void 0 ? void 0 : _c.match('/:path*', ({ serveStatic }) => serveStatic(targetPage));
        }
        else {
            // if not static, it can also mean we're in dev mode
            (_d = this.router) === null || _d === void 0 ? void 0 : _d.match('/:path*', ({ renderWithApp }) => renderWithApp());
            // BACKENDS.js not found error -> solve last, it's only performance related
            // this.router?.match('/:path*', renderNuxtPage)
        }
    }
    /**
     * Adds nuxt routes to router
     * @param {RouteGroup} group
     */
    addNuxtRoutes() {
        this.addPages();
        this.addAssets();
    }
    addPages() {
        var _a;
        // edgio acts as a server for static files only for this case
        if (this.config.target !== 'static')
            return;
        // output from npx nuxt generate
        (_a = this.router) === null || _a === void 0 ? void 0 : _a.static('dist');
    }
    /**
     * Adds routes for static assets, including /static and /.nuxt/static
     * @param group
     */
    addAssets() {
        var _a, _b, _c, _d, _e, _f;
        /* istanbul ignore next */
        (_a = this.router) === null || _a === void 0 ? void 0 : _a.static('static', {});
        if ((0, environment_1.isProductionBuild)()) {
            (_b = this.router) === null || _b === void 0 ? void 0 : _b.match('/service-worker.js', ({ serviceWorker }) => {
                serviceWorker(this.config.target === 'static'
                    ? (0, path_1.join)('dist', '_nuxt', 'service-worker.js')
                    : (0, path_1.join)(`${this.buildDir}`, 'dist', 'client', 'service-worker.js'));
            });
            (_c = this.router) === null || _c === void 0 ? void 0 : _c.match('/_nuxt/:path*', ({ cache, serveStatic }) => {
                this.config.target === 'static'
                    ? serveStatic((0, path_1.join)('dist', '_nuxt', ':path*'))
                    : serveStatic((0, path_1.join)(`${this.buildDir}`, 'dist', 'client', ':path*'), exports.browserAssetOpts);
                cache(FAR_FUTURE_CACHE_CONFIG);
            });
        }
        else {
            // webpack hot loader
            // TODO: enable once routehelper's stream method is implemented
            const streamHandler = ({ send }) => send('NOT IMPLEMENTED', 200);
            (_d = this.router) === null || _d === void 0 ? void 0 : _d.match('/__webpack_hmr/:path*', streamHandler);
            (_e = this.router) === null || _e === void 0 ? void 0 : _e.match('/_nuxt/:hash.hot-update.json', streamHandler);
            (_f = this.router) === null || _f === void 0 ? void 0 : _f.match('/_loading/:path*', streamHandler);
        }
    }
    log(...messages) {
        (0, environment_1.isProductionBuild)() && (0, environment_1.isLocal)() && console.log(...messages);
    }
}
exports.default = NuxtRoutes;
