"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const workbox_webpack_plugin_1 = require("workbox-webpack-plugin");
const path_1 = require("path");
const fs_1 = require("fs");
const NUXT_DIR = (0, path_1.join)(process.cwd(), '.nuxt', 'dist');
const OUTPUT_DIR = (0, path_1.join)(NUXT_DIR, 'client');
/**
 * This can be added to a nuxt.config.js configuration as a build plugin, to
 * allow a service worker to have the manifest injected when building for Edgio.
 *
 * Example nuxt.config.js:
 *
 * ```js
 *  build: {
 *    extend(config, { isClient }) {
 *      if (isClient) {
 *        config.plugins.push(new CreateServiceWorkerPlugin())
 *      }
 *    },
 *  }
 * ```
 */
class CreateServiceWorkerPlugin extends workbox_webpack_plugin_1.InjectManifest {
    constructor(config = {}) {
        super(Object.assign(Object.assign({}, config), { swSrc: (0, path_1.resolve)(process.cwd(), 'sw', 'service-worker.js'), swDest: 'service-worker.js', exclude: [/\/server\/.*/], manifestTransforms: [
                (manifestEntries) => {
                    console.log('> Creating service worker...');
                    const manifest = manifestEntries.filter(entry => entry.url !== '/_nuxt/LICENSES');
                    return { manifest, warnings: [] };
                },
            ] }));
    }
    handleEmit(compilation) {
        const _super = Object.create(null, {
            handleEmit: { get: () => super.handleEmit }
        });
        return __awaiter(this, void 0, void 0, function* () {
            //@ts-ignore
            yield _super.handleEmit.call(this, compilation);
            if (process.env.NODE_ENV !== 'production') {
                this.writeFile(compilation);
            }
        });
    }
    /**
     * Writes the service worker to disk in dev mode. Since Nuxt uses an in-memory fs in dev
     * mode, the only way the user can test the service worker is if we explictly write it to disk
     * so it can be served from Edgio.
     * @param compilation
     */
    writeFile(compilation) {
        if (!(0, fs_1.existsSync)(NUXT_DIR)) {
            (0, fs_1.mkdirSync)(NUXT_DIR);
        }
        if (!(0, fs_1.existsSync)(OUTPUT_DIR)) {
            (0, fs_1.mkdirSync)(OUTPUT_DIR);
        }
        (0, fs_1.writeFileSync)((0, path_1.join)(OUTPUT_DIR, 'service-worker.js'), compilation.assets['service-worker.js'].source(), 'utf8');
    }
}
exports.default = CreateServiceWorkerPlugin;
