"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const terminal_link_1 = __importDefault(require("terminal-link"));
const intersection_1 = __importDefault(require("lodash/intersection"));
const path_1 = require("path");
const customFrameworks = [
    '@adonisjs/framework',
    'express',
    'fastify',
    '@feathersjs/express',
    '@hapi/hapi',
    'koa',
    'micro',
];
/**
 * Checks for any of the custom frameworks that can be installed from create-nuxt-app
 * and warns the user on how to handle them if they are installed.
 * @param builder
 */
function checkForCustomFramework(builder) {
    const file = (0, path_1.join)(process.cwd(), 'package.json');
    let packageContents = JSON.parse(builder.readFileSync(file));
    const detectedFrameworks = (0, intersection_1.default)(Object.keys(packageContents.dependencies), customFrameworks);
    if (detectedFrameworks.length > 0) {
        console.warn(`${chalk_1.default.bgRed('WARNING:')} ${chalk_1.default.red(`It looks like you are using a custom framework:\n${detectedFrameworks
            .map((f) => ` - ${f}`)
            .join('\n')}\nThis will probably cause errors when running Edgio. See the ${(0, terminal_link_1.default)('Edgio Nuxt docs', 'https://docs.edg.io/guides/nuxt')} to learn more.`)}`);
    }
}
exports.default = checkForCustomFramework;
