"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateDependencies = void 0;
/* istanbul ignore file */
const config_1 = require("@nuxt/config");
const packageUtils_1 = require("@edgio/core/utils/packageUtils");
const chalk_1 = __importDefault(require("chalk"));
const NUXT_CORE_DEPENDENCY = '@nuxt/core';
/**
 * Ensures that package.json has the correct Nuxt dependencies defined
 */
function validateDependencies() {
    return __awaiter(this, void 0, void 0, function* () {
        const packageContents = (0, packageUtils_1.read)();
        const { dependencies } = packageContents;
        if (!dependencies[NUXT_CORE_DEPENDENCY]) {
            console.log(chalk_1.default.red.bold(`Error: You must add "${NUXT_CORE_DEPENDENCY}" as a dependency in package.json. ` +
                'Please update this file or run `edgio init` and try again.'));
            // We signal to the next process in chain that there was an error.
            process.exit(1);
        }
    });
}
exports.validateDependencies = validateDependencies;
/**
 * Optimizes the dependencies and devDependencies in package.json so that
 * the serverless build is as small as possible.
 */
function updateDependencies() {
    return __awaiter(this, void 0, void 0, function* () {
        const config = yield (0, config_1.loadNuxtConfig)();
        const packageContents = JSON.parse(JSON.stringify((0, packageUtils_1.read)())); // don't clone original ref
        const { dependencies, devDependencies } = packageContents;
        // move all dependencies not listed in modules to devDependencies to reduce bundle size
        /* istanbul ignore next  */
        for (let pkg in dependencies) {
            if (!config.modules.includes(pkg)) {
                devDependencies[pkg] = dependencies[pkg];
                delete dependencies[pkg];
            }
        }
        // use the same version of @nuxt/core as nuxt
        const { nuxt } = devDependencies;
        dependencies[NUXT_CORE_DEPENDENCY] = nuxt;
        delete devDependencies[NUXT_CORE_DEPENDENCY];
        (0, packageUtils_1.write)(JSON.stringify(packageContents, null, 2));
    });
}
exports.default = updateDependencies;
